@@ -17,7 +17,8 @@ import dropbox
 import hashlib
 import webbrowser
 import yaml
-from HandwrittenData import HandwrittenData
+# mine
+from hwrt.HandwrittenData import HandwrittenData
 import time
 import utils
 
